%%%Compare Samples GUI
function varargout = SampComp(varargin)
% SAMPCOMP M-file for SampComp.fig
%      SAMPCOMP, by itself, creates a new SAMPCOMP or raises the existing
%      singleton*.
%
%      H = SAMPCOMP returns the handle to a new SAMPCOMP or the handle to
%      the existing singleton*.
%
%      SAMPCOMP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SAMPCOMP.M with the given input arguments.
%
%      SAMPCOMP('Property','Value',...) creates a new SAMPCOMP or raises
%      the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before SampComp_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to SampComp_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help SampComp

% Last Modified by GUIDE v2.5 15-May-2011 22:08:11

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @SampComp_OpeningFcn, ...
                   'gui_OutputFcn',  @SampComp_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before SampComp is made visible.
function SampComp_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to SampComp (see VARARGIN)

% Choose default command line output for SampComp
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes SampComp wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = SampComp_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
if handles.GlobalCells~=0
    handles.EditNum=1;
end
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function SelectFilesTable_CreateFcn(hObject, eventdata, handles)
% hObject    handle to SelectFilesTable (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
hGenomeGems=getappdata(0,'hGenomeGems');
handles.Files=getappdata(hGenomeGems,'Files');
handles.GlobalCells=getappdata(hGenomeGems,'GlobalCells');
guidata(hObject, handles);
handles.SelectFilesTable=hObject;
set(handles.SelectFilesTable, 'Data',handles.Files);
if handles.GlobalCells ~=0
    SelectFilesTable_CellSelectionCallback(hObject,eventdata,handles);
end


function EditNum_Callback(hObject, eventdata, handles)
% hObject    handle to EditNum (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
handles.EditNum=get(hObject,'String')
guidata(hObject,handles) % Save the handles structure after adding data

% Hints: get(hObject,'String') returns contents of EditNum as text
%        str2double(get(hObject,'String')) returns contents of EditNum as a double


% --- Executes during object creation, after setting all properties.
function EditNum_CreateFcn(hObject, eventdata, handles)
% hObject    handle to EditNum (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in ShowBarGrph.
function ShowBarGrph_Callback(hObject, eventdata, handles)
% hObject    handle to ShowBarGrph (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%%Error - if file was not selected
if isfield(handles,'cells')==0
     h = msgbox('Please select a file. For more information see our manual page at http://www.tau.ac.il/~nshomron/GenomeGems/Manual.html','Missing Information','error')
end
f=handles.cells;
handles.GlobalCells=f;
for i=1:length(f)
    sanum(i)=str2num(handles.Files{f(i),1});
    path{i}=handles.Files{f(i),4};
end
TotalMatrix=SampCompare(sanum,handles.Files{f(1),2},handles.Files{f(1),3},path);
freqSNPs=GenerateFreqMatrix(TotalMatrix);
%%Error - if file was not selected
if ischar(handles.EditNum)==0
     h = msgbox('Please select a threshold. For more information see our manual page at http://www.tau.ac.il/~nshomron/GenomeGems/Manual.html','Missing Information','error')
end
if isempty(handles.EditNum)==1
     h = msgbox('Please select a threshold. For more information see our manual page at http://www.tau.ac.il/~nshomron/GenomeGems/Manual.html','Missing Information','error')
end
TresholdMatrix=GenerateTreshMatrix(freqSNPs,str2num(handles.EditNum));
NumberedMatrix=BarGraph(TresholdMatrix);
set(handles.SNPTable, 'Data', NumberedMatrix);
guidata(hObject, handles);
set(gcf,'CurrentAxes',handles.SNPAxes);
bar(NumberedMatrix(:,1),NumberedMatrix(:,3));
set( gca, 'xtick', [1:max(NumberedMatrix(:,1))])
colormap summer
axis([0,max(NumberedMatrix(:,1)),0,(max(NumberedMatrix(:,3))+1)])
axis 'auto x'
xlabel('SNP Number','FontName','Calibri');  ylabel('Frequency [number of samples containing the SNP]','FontName','Calibri');
title('Frequencies of SNPs-Bar View','FontName','Calibri');

%% Save Global Cells
hGenomeGems=getappdata(0,'hGenomeGems');
setappdata(hGenomeGems,'GlobalCells',handles.GlobalCells);

% --- Executes when selected cell(s) is changed in SelectFilesTable.
function SelectFilesTable_CellSelectionCallback(hObject, eventdata, handles)
% hObject    handle to SelectFilesTable (see GCBO)
% eventdata  structure with the following fields (see UITABLE)
%	Indices: row and column indices of the cell(s) currently selecteds
% handles    structure with handles and user data (see GUIDATA)
if handles.GlobalCells~=0
    eventdata.Indices=handles.GlobalCells;
end
index=eventdata.Indices;
handles.cells = index;
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function SNPTable_CreateFcn(hObject, eventdata, handles)
% hObject    handle to SNPTable (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called





% --- Executes during object creation, after setting all properties.
function SNPAxes_CreateFcn(hObject, eventdata, handles)
% hObject    handle to SNPAxes (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: place code in OpeningFcn to populate SNPAxes


% --- Executes during object creation, after setting all properties.
function axes1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to axes1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
imshow('ComSampTitle.jpg')
axis image
% Hint: place code in OpeningFcn to populate axes1


% --- Executes on button press in GoToSNPView.
function GoToSNPView_Callback(hObject, eventdata, handles)
% hObject    handle to GoToSNPView (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
SNPView


% --- Executes during object creation, after setting all properties.
function GoToSNPView_CreateFcn(hObject, eventdata, handles)
% hObject    handle to GoToSNPView (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes on button press in BackToMain.
function BackToMain_Callback(hObject, eventdata, handles)
% hObject    handle to BackToMain (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
GenomeGems
